@@ -27,4 +27,16 @@ class GetInstrumentsRequest(ApiRequest):
             self.add_query_param("symbols", ",".join(symbols))
     
     def set_category(self, category):
-        self.add_query_param("category", category)
\ No newline at end of file
+        self.add_query_param("category", category)
+
+    def set_status(self, status):
+        if status:
+            self.add_query_param("status", status)
+
+    def set_last_instrument_id(self, last_instrument_id):
+        if last_instrument_id:
+            self.add_query_param("last_instrument_id", last_instrument_id)
+
+    def set_page_size(self, page_size):
+        if page_size:
+            self.add_query_param("page_size", page_size)
